# svo-slicer
a package to slice svo files into a deliverable compressed folder

# requirements
1. datetime
2. shutil
3. pyzed (check ZED SDK installation guide for linux or windows)
4. numpy
5. python-opencv
6. argparse
7. zipfile

# installation
1. colne this repo
